@@ -16,6 +16,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <err.h>
 #include <sys/types.h>
@@ -254,8 +258,9 @@ get_memory_usage (guint64 *memory_total, guint64 *memory_available, guint64 *mem
 	*memory_available = *memory_free + *memory_cache + *memory_buffers;
 
 	/* get swap stats */
+	*swap_total = *swap_free = 0;
 	if ((nswap = swapctl(SWAP_NSWAP, 0, 0)) == 0)
-		errx(1,"failed to get swap device count");
+		return TRUE;
 
 	if ((swdev = calloc(nswap, sizeof(*swdev))) == NULL)
 		errx(1,"failed to allocate memory for swdev structures");
@@ -266,7 +271,6 @@ get_memory_usage (guint64 *memory_total, guint64 *memory_available, guint64 *mem
 	}
 
 	/* Total things up */
-	*swap_total = *swap_free = 0;
 	for (i = 0; i < nswap; i++) {
 		if (swdev[i].se_flags & SWF_ENABLE) {
 			*swap_free += (swdev[i].se_nblks - swdev[i].se_inuse);
