@@ -153,7 +153,7 @@ get_task_cmdline (Task *task)
 	for (i = 0; (c = fgetc (file)) != EOF && i < (gint)sizeof (task->cmdline) - 1; i++)
 		task->cmdline[i] = (c == '\0') ? ' ' : (gchar)c;
 	task->cmdline[i] = '\0';
-	if (task->cmdline[i-1] == ' ')
+	if (i > 0 && task->cmdline[i-1] == ' ')
 		task->cmdline[i-1] = '\0';
 	fclose (file);
 
@@ -268,7 +268,7 @@ get_task_details (GPid pid, Task *task)
 			 &idummy,	// cutime " waited for children in user mode
 			 &idummy,	// cstime " system mode
 			 &idummy,	// priority (nice value + fifteen)
-			(gint*)&task->prio, // nice range from 19 to -19
+			 &task->prio, // nice range from 19 to -19
 			 &idummy,	// hardcoded 0
 
 			 &idummy,	// itrealvalue time in jiffies to next SIGALRM send to this process
