@@ -15,6 +15,10 @@
 #include <string.h>
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib.h>
 
 #include "task-manager.h"
