@@ -243,7 +243,7 @@ model_update_tree_iter (XtmTaskManager *manager, GtkTreeIter *iter, glong timest
 	gchar *background, *foreground;
 #ifdef HAVE_WNCK
 	App *app = manager->app_manager != NULL ? xtm_app_manager_get_app_from_pid (manager->app_manager, task->pid) : NULL;
-	GdkPixbuf *icon = NULL;
+	cairo_surface_t *surface = NULL;
 #endif
 
 	vsz = g_format_size_full (task->vsz, G_FORMAT_SIZE_IEC_UNITS);
@@ -256,15 +256,15 @@ model_update_tree_iter (XtmTaskManager *manager, GtkTreeIter *iter, glong timest
 	gtk_tree_model_get (model, iter, XTM_PTV_COLUMN_TIMESTAMP, &old_timestamp, XTM_PTV_COLUMN_STATE, &old_state,
 			XTM_PTV_COLUMN_BACKGROUND, &background, XTM_PTV_COLUMN_FOREGROUND, &foreground,
 #ifdef HAVE_WNCK
-			XTM_PTV_COLUMN_ICON, &icon,
+			XTM_PTV_COLUMN_ICON, &surface,
 #endif
 			-1);
 
 #ifdef HAVE_WNCK
-	if (icon != NULL)
-		g_object_unref (icon);
+	if (surface != NULL)
+		cairo_surface_destroy (surface);
 	else if (app != NULL)
-		gtk_list_store_set (GTK_LIST_STORE (model), iter, XTM_PTV_COLUMN_ICON, app->icon, -1);
+		gtk_list_store_set (GTK_LIST_STORE (model), iter, XTM_PTV_COLUMN_ICON, app->surface, -1);
 
 	if (app != NULL && full_cmdline == FALSE)
 	{
@@ -333,9 +333,12 @@ model_update_tree_iter (XtmTaskManager *manager, GtkTreeIter *iter, glong timest
 static gboolean
 task_list_find_for_pid (GArray *task_list, GPid pid, Task **task, guint *idx)
 {
-	Task *task_tmp, tkey;
-	tkey.pid = pid;
-	task_tmp = bsearch(&tkey, task_list->data, task_list->len, sizeof(Task), task_pid_compare_fn);
+	Task *task_tmp = NULL, tkey;
+
+	if (task_list->data != NULL) {
+		tkey.pid = pid;
+		task_tmp = bsearch(&tkey, task_list->data, task_list->len, sizeof(Task), task_pid_compare_fn);
+	}
 
 	if (NULL != task)
 	{
@@ -594,3 +597,21 @@ task_pid_compare_fn(gconstpointer a, gconstpointer b)
 {
 	return (((const Task*)a)->pid - ((const Task*)b)->pid);
 }
+
+/* About the constants used below, see for example: https://stackoverflow.com/a/596243 */
+gboolean
+xtm_gtk_widget_is_dark_mode (GtkWidget *widget)
+{
+	GtkStyleContext *context;
+	GdkRGBA *color;
+	double luminosity;
+	gboolean dark_mode;
+
+	context = gtk_widget_get_style_context (gtk_widget_get_toplevel (widget));
+	gtk_style_context_get (context, GTK_STATE_FLAG_NORMAL, GTK_STYLE_PROPERTY_BACKGROUND_COLOR, &color, NULL);
+	luminosity = (0.2126 * color->red + 0.7152 * color->green + 0.0722 * color->blue);
+	gdk_rgba_free (color);
+	dark_mode = (luminosity < 0.5);
+
+	return dark_mode;
+}
